@@ -25,5 +25,10 @@ __copyright__ = "Copyright 2022 Greg Albrecht"
 __license__ = "Apache License, Version 2.0"
 
 
-# PyTAK CLI tool boilerplate:
-pytak.cli(__name__.split(".")[0])
+def main() -> None:
+    # PyTAK CLI tool boilerplate:
+    pytak.cli(__name__.split(".")[0])
+
+
+if __name__ == '__main__':
+    main()
\ No newline at end of file
